@@ -13,11 +13,15 @@
 #' and an INFO dataframe with metadata. 
 #'
 #' @param yearStart numeric specifying the starting date (expressed as decimal years, for example 1989.0) for the plot
-#' @param yearEnd numeric specifiying the ending date for the plot 
+#' @param yearEnd numeric specifying the ending date for the plot 
 #' @param eList named list with at least the Daily, Sample, and INFO dataframes
 #' @param tinyPlot logical variable, if TRUE plot is designed to be short and wide, default is FALSE.
-#' @param concMax number specifying the maximum value to be used on the vertical axis, default is NA (which allows it to be set automatically by the data)
-#' @param printTitle logical variable if TRUE title is printed, if FALSE title is not printed (this is best for a multi-plot figure)
+#' @param plotGenConc logical variable. If \code{TRUE}, annual concentration points
+#' from \code{WRTDSKalman} output are plotted, if \code{FALSE} WRTDS concentration is plotted, 
+#' @param concMax number specifying the maximum value to be used on the vertical axis,
+#' default is NA (which allows it to be set automatically by the data)
+#' @param printTitle logical variable if TRUE title is printed, if FALSE title is
+#' not printed (this is best for a multi-plot figure)
 #' @param cex numerical value giving the amount by which plotting symbols should be magnified
 #' @param cex.main magnification to be used for main titles relative to the current setting of cex
 #' @param cex.axis magnification to be used for axis annotation relative to the current setting of cex
@@ -38,11 +42,20 @@
 #' eList <- Choptank_eList
 #' # Water year:
 #' plotConcTimeDaily(eList)
-#' plotConcTimeDaily(eList, yearStart=1998,yearEnd=2001)
-plotConcTimeDaily<-function(eList, yearStart=NA, yearEnd=NA, tinyPlot = FALSE, 
-                            concMax = NA, printTitle = TRUE,cex=0.8, cex.axis=1.1,randomCensored=FALSE,
-                            cex.main=1.1, customPar=FALSE,col="black",lwd=1,
-                            prettyDate=TRUE, usgsStyle = FALSE,...){
+#' plotConcTimeDaily(eList, 
+#'                   yearStart = 1998,
+#'                   yearEnd = 2001,
+#'                   plotGenConc = FALSE)
+plotConcTimeDaily <- function(eList, 
+                              yearStart = NA, yearEnd = NA, tinyPlot = FALSE, 
+                              concMax = NA, 
+                              printTitle = TRUE, 
+                              plotGenConc = TRUE,
+                              cex = 0.8, cex.axis = 1.1,
+                              randomCensored = FALSE,
+                              cex.main = 1.1, customPar = FALSE,
+                              col = "black", lwd = 1,
+                              prettyDate = TRUE, usgsStyle = FALSE,...){
 
   localINFO <- getInfo(eList)
   localSample <- getSample(eList)
@@ -59,33 +72,61 @@ plotConcTimeDaily<-function(eList, yearStart=NA, yearEnd=NA, tinyPlot = FALSE,
     paStart <- 10
   } 
   
+  if(plotGenConc){
+    if(!all((c("GenFlux","GenConc") %in% names(eList$Daily)))){
+      message("plotGenConc = TRUE requires running WRTDSKalman
+              on eList. Switching to WRTDS concentration.")
+      plotGenConc <- FALSE
+    }
+  }
+  
   localSample <- if(paLong == 12) localSample else selectDays(localSample, paLong,paStart)
   localDaily <- if(paLong == 12) localDaily else selectDays(localDaily,paLong,paStart)
   
-  title2<-if(paLong==12) "" else setSeasonLabelByUser(paStartInput=paStart,paLongInput=paLong)
+  title2 <- if(paLong == 12) "" else setSeasonLabelByUser(paStartInput=paStart,paLongInput=paLong)
   
-  subSample<-localSample[localSample$DecYear>=yearStart & localSample$DecYear<= yearEnd,]
-  subDaily<-localDaily[localDaily$DecYear>=yearStart & localDaily$DecYear <= yearEnd,]
+  subSample <- localSample[localSample$DecYear >= yearStart &
+                             localSample$DecYear<= yearEnd,]
+  subDaily <- localDaily[localDaily$DecYear >= yearStart &
+                           localDaily$DecYear <= yearEnd,]
   
-  xSample<-subSample$DecYear
-  xDaily<-subDaily$DecYear
+  xSample <- subSample$DecYear
+  xDaily <- subDaily$DecYear
   
-  Uncen<-subSample$Uncen
+  Uncen <- subSample$Uncen
   
-  plotTitle<-if(printTitle) paste(localINFO$shortName,"\n",localINFO$paramShortName,"\n","Observed and Estimated Concentration versus Time") else ""
+  plotTitle <- if(printTitle) {
+    paste(localINFO$shortName, "\n",
+          localINFO$paramShortName,"\n",
+          "Observed and Estimated Concentration versus Time") 
+    } else {
+      ""
+    }
+  
+  if(plotGenConc){
+    concentration <- subDaily$GenConc
+  } else {
+    concentration <- subDaily$ConcDay
+  }
   
   ###################################
   
   yBottom <- 0 #Not specified within script, added under assumption that it's always zero based on ylim definition in this function
   
-  xInfo <- generalAxis(x=xSample, minVal=yearStart, maxVal=yearEnd, tinyPlot=tinyPlot,padPercent=0,prettyDate=prettyDate)  
+  xInfo <- generalAxis(x = xSample,
+                       minVal = yearStart,
+                       maxVal = yearEnd,
+                       tinyPlot = tinyPlot,
+                       padPercent = 0,
+                       prettyDate = prettyDate)  
   
   if(!randomCensored){
     
-    yLow<-subSample$ConcLow
-    yHigh<-subSample$ConcHigh
+    yLow <- subSample$ConcLow
+    yHigh <- subSample$ConcHigh
+    
+    yCombined <- c(yHigh, concentration)
     
-    yCombined <- c(yHigh,subDaily$ConcDay)
     yInfo <- generalAxis(x = yCombined, minVal = yBottom, maxVal = concMax, 
                          tinyPlot = tinyPlot, padPercent = 5,units=localINFO$param.units,
                          usgsStyle = usgsStyle)
@@ -101,24 +142,29 @@ plotConcTimeDaily<-function(eList, yearStart=NA, yearEnd=NA, tinyPlot = FALSE,
     if(!("rObserved" %in% names(localSample))){
       eList <- makeAugmentedSample(eList)
       localSample <- eList$Sample
-      subSample<-localSample[localSample$DecYear>=yearStart & localSample$DecYear<= yearEnd,]
+      subSample <- localSample[localSample$DecYear>=yearStart & localSample$DecYear<= yearEnd,]
     }
     
     yHigh <- subSample$rObserved
-    
-    yCombined <- c(yHigh,subDaily$ConcDay)
+
+    yCombined <- c(yHigh, concentration)
     yInfo <- generalAxis(x = yCombined, minVal = yBottom, maxVal = concMax, 
                          tinyPlot = tinyPlot, padPercent = 5,units=localINFO$param.units,usgsStyle = usgsStyle)
-    genericEGRETDotPlot(x=xSample[subSample$Uncen == 1], y=yHigh[subSample$Uncen == 1], xTicks=xInfo$ticks, yTicks=yInfo$ticks,
-                        xlim=c(xInfo$bottom,xInfo$top), ylim=c(yInfo$bottom,yInfo$top),
-                        ylab=yInfo$label,plotTitle=plotTitle,cex.axis=cex.axis,col=col,lwd=lwd,cex=cex,
-                        cex.main=cex.main, tinyPlot=tinyPlot,customPar=customPar, xDate=TRUE,...
+    genericEGRETDotPlot(x = xSample[subSample$Uncen == 1], 
+                        y = yHigh[subSample$Uncen == 1],
+                        xTicks = xInfo$ticks, yTicks = yInfo$ticks,
+                        xlim = c(xInfo$bottom, xInfo$top), ylim = c(yInfo$bottom,yInfo$top),
+                        ylab = yInfo$label, plotTitle = plotTitle, cex.axis=cex.axis,col=col,lwd=lwd,cex=cex,
+                        cex.main = cex.main, tinyPlot = tinyPlot, customPar=customPar, xDate=TRUE,...
     )
-    points(x=xSample[Uncen == 0], y=yHigh[Uncen == 0], pch=1,cex=cex,col=col)
+    points(x = xSample[Uncen == 0], 
+           y = yHigh[Uncen == 0],
+           pch = 1, cex = cex, col = col)
     
   }
   
-  lines(x=xDaily, y=subDaily$ConcDay, type="l",col=col,lwd=lwd)
-  if (!tinyPlot) mtext(title2,side=3,line=-1.5)
+  lines(x = xDaily, y = concentration, 
+        type = "l",col = col, lwd = lwd)
+  if (!tinyPlot) mtext(title2, side = 3, line = -1.5)
   
 }
\ No newline at end of file
